# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetKubernetesNodePoolSnapshotResult',
    'AwaitableGetKubernetesNodePoolSnapshotResult',
    'get_kubernetes_node_pool_snapshot',
    'get_kubernetes_node_pool_snapshot_output',
]

@pulumi.output_type
class GetKubernetesNodePoolSnapshotResult:
    """
    A collection of values returned by getKubernetesNodePoolSnapshot.
    """
    def __init__(__self__, id=None, name=None, resource_group_name=None, source_node_pool_id=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if source_node_pool_id and not isinstance(source_node_pool_id, str):
            raise TypeError("Expected argument 'source_node_pool_id' to be a str")
        pulumi.set(__self__, "source_node_pool_id", source_node_pool_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="sourceNodePoolId")
    def source_node_pool_id(self) -> str:
        """
        The ID of the source Node Pool.
        """
        return pulumi.get(self, "source_node_pool_id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        return pulumi.get(self, "tags")


class AwaitableGetKubernetesNodePoolSnapshotResult(GetKubernetesNodePoolSnapshotResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKubernetesNodePoolSnapshotResult(
            id=self.id,
            name=self.name,
            resource_group_name=self.resource_group_name,
            source_node_pool_id=self.source_node_pool_id,
            tags=self.tags)


def get_kubernetes_node_pool_snapshot(name: Optional[str] = None,
                                      resource_group_name: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKubernetesNodePoolSnapshotResult:
    """
    Use this data source to access information about an existing Kubernetes Node Pool Snapshot.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.containerservice.get_kubernetes_node_pool_snapshot(name="example",
        resource_group_name="example-resources")
    ```


    :param str name: The name of the Kubernetes Node Pool Snapshot.
    :param str resource_group_name: The name of the Resource Group in which the Kubernetes Node Pool Snapshot exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:containerservice/getKubernetesNodePoolSnapshot:getKubernetesNodePoolSnapshot', __args__, opts=opts, typ=GetKubernetesNodePoolSnapshotResult).value

    return AwaitableGetKubernetesNodePoolSnapshotResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        source_node_pool_id=pulumi.get(__ret__, 'source_node_pool_id'),
        tags=pulumi.get(__ret__, 'tags'))


@_utilities.lift_output_func(get_kubernetes_node_pool_snapshot)
def get_kubernetes_node_pool_snapshot_output(name: Optional[pulumi.Input[str]] = None,
                                             resource_group_name: Optional[pulumi.Input[str]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetKubernetesNodePoolSnapshotResult]:
    """
    Use this data source to access information about an existing Kubernetes Node Pool Snapshot.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.containerservice.get_kubernetes_node_pool_snapshot(name="example",
        resource_group_name="example-resources")
    ```


    :param str name: The name of the Kubernetes Node Pool Snapshot.
    :param str resource_group_name: The name of the Resource Group in which the Kubernetes Node Pool Snapshot exists.
    """
    ...
